import { parser } from '@astroapps/evaluator';
import { LRLanguage, indentNodeProp, delimitedIndent, foldNodeProp, foldInside, LanguageSupport } from '@codemirror/language';
import { styleTags, tags } from '@lezer/highlight';

const EvalLanguage = LRLanguage.define({
    parser: parser.configure({
        props: [
            indentNodeProp.add({
                Application: delimitedIndent({ closing: ")", align: false })
            }),
            foldNodeProp.add({
                Application: foldInside
            }),
            styleTags({
                Reference: tags.variableName,
                BooleanLiteral: tags.bool,
                String: tags.string,
                Number: tags.number,
                "( )": tags.paren
            })
        ]
    }),
    languageData: {
        commentTokens: { line: ";" }
    }
});
function Evaluator() {
    return new LanguageSupport(EvalLanguage);
}

export { EvalLanguage, Evaluator };
